clear 
set more off
cap log close
set logtype text, perm
log using cito_data, replace

/* MERGE SCHOOL INFO TO CITO TEST SCORE DATA */
use raw/cito92orig, clear

sort jaar brin
merge jaar brin using raw/LL, uniqusing

tab _merge
keep if _merge==3
drop _merge

save data/cito92, replace


/*=================*/
/* CITO 1999-2003  */
/*=================*/

*** for some schools in the cito test score data file, the brincode (school code)
*** is wrong; schools merged but the old code is used in the datafile
*** to make sure that teh test score data can be merged with data on schools
*** we make a datafile with schools for which the brincode has changed, which
*** includes the old and the new code

use raw/cito9903orig, clear
keep brin jaar
keep if brin!=""
bys brin jaar: keep if _n==1
merge 1:1 brin jaar using raw/LL
keep if _merge==1
drop _merge
rename jaar jaarcito
merge m:1 brin using raw/fusies9103
keep if _merge==3

keep jaarcito brin brnew
rename jaarcito jaar

save data/oude_en_nieuwe_brin_cito9903, replace


*** CREATE DATAFILE WITH TESTCORES FROM 1999-2004

use raw/cito9903orig, clear

/* DROP MISSING BRINCODES */

encode brin, gen(brin2)

sum cito if brin2~=.
sum cito if brin2==.

keep if brin2~=.
drop brin2


** replace old brin by new brin in case of merger in year of test
** nessesary in order to merge with data with school info (LL.dta)

merge m:1 brin jaar using data/oude_en_nieuwe_brin_cito9903

replace brin=brnew if _merge==3
drop _merge brnew


/* SCHOOLGEGEVENS AAN CITO DATA PLAKKEN */

keep if jaar~=.
sort jaar brin
merge jaar brin using raw/LL, uniqusing
tab _merge

keep if _merge==3
drop _merge

save data/cito03, replace


*** MERGE CITO 1992 AND CITO 1999-2003 

append using data/cito92


/* GENERATE SCHOOLSIZE VARIABLE */

forvalues i=1/5 {
	rename aantal`i' Saantal`i'
}
rename total Schoolsize



/* MERGE MUNICIPALITY CODES TO SCHOOL CODES */ 

sort brin
merge brin using data/brin_gem_1obsperbrin, uniqusing
tab _merge

keep if _merge==3
drop _merge



/* DROP MUNICIPALITIES THAT MERGED BETWEE 1992 AND 2003 */

sort gemcode
merge gemcode using data/gemcode_geenher_9203, uniqusing
tab _merge
keep if _merge==3
drop _merge



/* MERGE WITH MUNICIPALITY INFO */

sort gemcode jaar

merge gemcode jaar using data/geminfo_multipleyears, uniqusing
tab _merge

keep if _merge==3
drop _merge

save data/cito92_03, replace


/* maak variabele voor balanced panel van gemeenten */
/* alleen gemeentes die in alle jaren (1992,2003) cito gegevens hebben */

*** KEEP ONLY MINICIPALITIES WITH TEST SCORE DATA IN ALL YEARS

bys gemcode jaar: keep if _n==1

keep if jaar==1992 | jaar==2003
bys gemcode: gen teller=_N
keep if teller==2

bys gemcode: keep if _n==1
gen gemin1992en2003=1
keep gemcode gemin1992en2003
sort gemcode

save data/citogem92en03, replace 

use data/cito92_03, clear

sort gemcode

merge gemcode using data/citogem92en03, uniqusing

drop _merge


/* GENERATE VARIABLES */


gen lnschools = ln(nschools)
gen lnpupils = ln(npupils)
gen lbevolking = ln(bevolking)
gen share190= aantal5/npupils
gen share125=aantal2/npupils
gen avrschoolsize=npupils/nschools

gsort jaar - bevolking
bys jaar : g grote = sum(gemcode != gemcode[_n - 1])

gen percentww=100*ww/bevolking
gen percentabw=100*abw/bevolking
gen percentbenefits=100*(abw+ww)/bevolking


gen share125school=Saantal2/Schoolsize
gen share190school=Saantal5/Schoolsize


bys gemcode : egen y92grote20    = mean(cond(jaar==1992, grote<=20, .))



/* GENERATE INSTRUMENT LOPHEF */

gen lophef     = ln(ophef1992) if jaar==1992
replace lophef = ln(ophef1994) if jaar>=1999


/* generate log school size*/

gen lschoolsize=ln(Schoolsize)

keep ntesttakers cito lnschools lophef lschoolsize lbevolking share190* share125* ophef1992 ophef1994 lnpupils nschools gemin1992en2003 ///
 gemcode brin jaar  y92grote20 urban  opheffingsnorm avrschoolsize npupils bevolking Schoolsize aantal* Saantal* percentbenefits
 
 

save data/CITO_MULTIPLE_YEARS, replace


