clear
set mem 500m
set more off
cap log close
set logtype text, perm
log using crgeminfo, replace

**************************************************************************
** brin_gem.dta is a datafile with for each school a code (brincode)    **
** and the code of the municipality in which the school is located      **
** some schools have multiple locations, keep only main location        **
** municipality code is only correct for municipalities that did't merge**
**************************************************************************

use raw/brin_gem, clear
bysort brin (brinvest): keep if _n==1
keep brin gemcode
destring gemcode, replace
sort brin
save data/brin_gem_1obsperbrin, replace 

**************************************************************************
** Merge data with minimum school size rules and data on number of      ** 
** inhabitants per municipality                                         **
** nr. inhabitants measured on 1 Januari                                **
** minimum school size rules hold per 1 august                          **
**************************************************************************

use raw/opheffingsnormen1994_2003, clear
merge gemcode using raw/bevolking90_05, unique sort
drop _merge
renpfix bevolking9 bevolking199
renpfix bevolking0 bevolking200

*** OLD MINIMUM SCHOOL SIZE RULE
forvalues y=1991/1993 {
	recode bevolking`y' (0/24999=50) (25000/49999=75) (50000/99999=100) (100000/max=125), gen(opheffingsnorm`y')
}

reshape long opheffingsnorm bevolking, i(gemcode) j(jaar)
sort jaar gemcode
save data/bevolking_ophef, replace

************************************************************************
** Make a datafile with municipality codes, only for those that       **
** did not merge between 1992-2003                                    **
************************************************************************

use raw/gemeentelijkeherindeling_schooljaar_91_06, clear
bys gemcode1992: gen n92 = _N
bys gemcode2004: gen n04 = _N
drop if n92!=n04 | gemcode1992!=gemcode2004 | gemcode1992==.
keep gemcode1992
rename gemcode1992 gemcode
bys gemcode: keep if _n==1
save data/gemcode_geenher_9203, replace 

************************************************************************
** Make a datafile with the number of schools and number of pupils    **
** for the municipalities that did not merge                          **
************************************************************************

use raw/LL, clear

sort brin
merge brin using data/brin_gem_1obsperbrin
keep if _merge==3
drop _merge

sort gemcode
merge gemcode using data/gemcode_geenher_9203
ta _mer
keep if _merge==3
drop _merge

// add municipality info (a.o. minimum school size rules)
sort jaar gemcode
merge jaar gemcode using data/bevolking_ophef
keep if _merge==3
drop _merge

bys jaar gemcode: egen npupils = sum(total)

collapse (count) nschools = total (mean) opheffingsnorm  bevolking npupils (sum) aantal? , by(gemcode jaar)


forv y=1992/2003 {
		bys gemcode: egen nschools`y' = max(nschools*(jaar==`y'))
		bys gemcode: egen npupils`y' = max(npupils*(jaar==`y'))
		bys gemcode: egen ophef`y' = max(opheffingsnorm*(jaar==`y'))
			}

merge gemcode jaar using raw/opp_pop411, unique sort

tab _merge
drop if _merge==2
drop _merge

bys gemcode: egen oppland95=max(oppland*(jaar==1995))
replace oppland=oppland95 if jaar<1995


/* Merge with info on benefits */

sort gemcode jaar

merge 1:1 gemcode jaar using raw/controlvariablesCBS.dta
drop if _merge==2
drop _merge
rename (abwuitkeringen wwuitkeringen) (abw ww)

*** merge with info on degree of urbaniziation in 1996
merge m:1 gemcode using raw/stedelijkheidgemcode1996

tab _merge
keep if _merge==3
drop _merge

gen urban=0
replace urban=1 if stedcode>=2



sort gemcode jaar

compress
save data/geminfo_multipleyears, replace

