clear all
set more off
set scheme s1mono

/*===========================================*/
/* FIGURE 1:  OLD AND NEW CLOSING DOWN RULES */
/*===========================================*/

use data/geminfo_multipleyears, clear

bys gemcode: gen opheffingold = ophef1992
bys gemcode: gen opheffingnew = ophef1994
label var opheffingold "Old rule"
label var opheffingnew "New rule"
keep if jaar==1992

/* OLD AND NEW CLOSING DOWN RULE BY NUMBER OF INHABITANTS */ 
replace bevolking = bevolking / 1000
twoway (connected opheffingold bevolking, sort lcolor(black) lwidth(medium) msymbol(circle) mcolor(black) ) ///
 (scatter opheffingnew bevolking, sort xscale(log) mcolor(red) msymbol(X)) ///
 , ytitle(Minimum school size rule) ytitle(, size(medlarge) margin(small)) ///
 xtitle(Number of inhabitants (1000s)) xtitle(, size(medlarge) margin(small)) ///
 xlabel(1 2 5 10 25 50 100 200 400 800) legend(ring(0) pos(5) col(1)) ///
 ylabel(0(25)200, angle(horiz)) plotreg(lpat(blank)) name(fig1a, replace)

*graph export old_new_rules_inhabitants.pdf, replace

/* OLD AND NEW CLOSING DOWN RULE BY PUPIL DENSITY */ 
gen pupildens = pop411 / oppland
twoway (scatter opheffingnew pupildens, sort mcolor(red) msymbol(X)) ///
 (scatter opheffingold pupildens, mcolor(black) msymbol(circle)), ///
 ytitle(minimum school size rule) ytitle(, margin(small) size(medlarge) ) xtitle(Pupil density) ///
 xtitle(, margin(small) size(medlarge) ) ///
 legend(on order(2 1) size(medium) position(4) ring(0) col(1)) ///
 ylabel(0(25)200,angle(horiz)) plotreg(lpat(blank))  name(fig1b, replace)

*graph export old_new_rules_pupildensity.pdf, replace


/*==========================================================================================*/
/* FIGURE 2: CHANGE IN AVERAGE NR SCHOOLS AND AVERAGE MIN SCHOOL SIZE BETWEEN 1991 AND 2004 */
/*==========================================================================================*/
use raw/nschools_npupils9192, clear
rename nschools1991 nschools
rename npupils1991 npupils
g jaar = 1991
append using data/geminfo_multipleyears

bys gemcode (jaar): replace opheffingsnorm = opheffingsnorm[_n + 1] if jaar==1991
label var opheffingsnorm "Average minimum school size"

cap g ssize = npupils / nschools

collapse ssize nschools opheffingsnorm if jaar<=2004, by(jaar)
label var nschools "Average nr. schools"

gen ophef2 = opheffingsnorm if !(jaar==1994 | jaar==1995)
label var ophef2 "Average minimum school size"

//       (connected ophef2 jaar, yaxis(2) mcolor(red) msymbol(circle_hollow) lpattern(solid) lcolor(red)) ///
//       (scatter opheffingsnorm jaar, yaxis(2) mcolor(red) msymbol(circle_hollow)) ///

g ymax = 17 if inrange(jaar, 1992, 1996)
g ymin = 13 if inrange(jaar, 1992, 1996)

twoway (rarea ymax ymin jaar, col(bluishgray) fcol(bluishgray)) ///
	   (connected nschools jaar, mcolor(black) msymbol(S) lpat(solid)) ///
       (connected opheffingsnorm jaar, yaxis(2) mcolor(red) msymbol(none) lpattern(shortdash) lcolor(red) connect(stairstep)) ///
       (scatter opheffingsnorm jaar, yaxis(2) mcolor(red) msymbol(circle_hollow) lpattern(solid) lcolor(red)) ///
       (scatter ophef2 jaar, yaxis(2) mcolor(red) msymbol(circle)) ///
	   , /// options:
	yscale(range(13.5 16.6)) xtitle(Year) xlabel(1991(2)2003) ///
	ytitle("Average nr. of schools") ///
	ytitle("Average minimum school size", axis(2)) ///
	ylabel(, angle(horiz)) ///
	ylabel(, axis(2) angle(horiz)) ///
	xmtick(1992(2)2002) ///
	plotreg(lpat(blank)) legend(off) ///
	legend(order(2 "Nr. of schools" 3 "Min. school size") rows(1)) ///
	name(fig2a, replace)
 
*graph export average_nrschools_ophef.pdf, replace



replace ymax = 220 if inrange(jaar, 1992, 1996)
replace ymin = 155 if inrange(jaar, 1992, 1996)

twoway (rarea ymax ymin jaar, col(bluishgray) fcol(bluishgray)) ///
	   (connected ssize jaar, mcolor(black) msymbol(S) lpat(solid)) ///
       (connected opheffingsnorm jaar, yaxis(2) mcolor(red) msymbol(none) lpattern(shortdash) lcolor(red) connect(stairstep)) ///
       (scatter opheffingsnorm jaar, yaxis(2) mcolor(red) msymbol(circle_hollow) lpattern(solid) lcolor(red)) ///
       (scatter ophef2 jaar, yaxis(2) mcolor(red) msymbol(circle)) ///
	   , /// options:
	yscale(range(155 220)) xtitle(Year) xlabel(1991(2)2003) ///
	ytitle("Average school size") ///
	ytitle("Average minimum school size", axis(2)) ///
	ylabel(, angle(horiz)) ///
	ylabel(, axis(2) angle(horiz)) ///
	xmtick(1992(2)2002) ///
	plotreg(lpat(blank)) legend(off) ///
 	legend(order(2 "School size" 3 "Min. school size") rows(1)) ///
	name(fig2b, replace)
 
*graph export average_ssize_ophef.pdf, replace

/*==========================================================*/
/* FIGURE 3: KERNEL DENSITY OF SCHOOL SIZE IN 1992 AND 2003 */
/*==========================================================*/
use raw/LL, clear
twoway (kdensity total if jaar==1992, lwidth(medthin) lcolor(red) lpattern(solid)) ///
       (kdensity total if jaar==2003, lwidth(medthin) lcolor(black) lpattern(shortdash)), ///
   ytitle(Density) ylabel(,angle(0)) ///
   xtitle(School size) xlabel(0(200)1250) legend(off) plotreg(lpat(blank)) ///
   name(fig3, replace)

*graph export kdensity_schoolsize.pdf, replace


