
clear all
set more off
cap log close

log using leo, replace text
use raw/p1457d, clear

** only schools from reference group
keep if code=="r"

// generate schoolsize variables
gen schoolsize = v3tot
gen schoolsize2 = schoolsize^2
gen lnschoolsize = ln(schoolsize)

// generate variables potentially affected by school size due to economies of scale
gen groep = v1
lab var groep "number of classes at school" 

gen combi = v2
lab var combi "number of classes with multiple grades"

gen ratiocombigroep = combi / groep

gen fulltimedir = v5a_1>0
lab var fulltimedir "school has 1 full time principal"

gen remedial = v5d_1>0 | v5d_2>0
lab var remedial "school has remedial teacher"

gen pcdirgeeftles = v57_3/100
lab var pcdirgeeftles "share of time principal teaches"

// generate variable reflecting contact with parents
forvalues i=1/8 {
	replace v48_`i' = v48_`i' - 1
}

lab var v48_5 "agreement parents attending parent-teacher meetings"
lab var v48_6 "agreement discussing the school report of the students"
lab var v48_7 "agreement time spend on the different subjects"
lab var v48_8 "agreement minimum goals that students should achieve"


gen extracurricular=v49-1
label var extracurricular "Probability school is involved in extracurricular parent-pupil activities"



//lnschoolsize

keep if ratiocombigroep~=. & fulltimedir~=. & remedial~=. & pcdirgeeftles~=. & v48_5~=. & v48_6~=. & v48_7~=. & v48_8~=.


regress pcdirgeeftles lnschoolsize, robust
est sto row1
regress fulltimedir lnschoolsize, robust
est sto row2
regress ratiocombigroep lnschoolsize, robust
est sto row3
regress remedial lnschoolsize, robust
est sto row4
regress extracurricular lnschoolsize, robust
est sto row5

regress v48_5 lnschoolsize, robust
est sto row6
regress v48_6 lnschoolsize, robust
est sto row7
regress v48_7 lnschoolsize, robust
est sto row8
regress v48_8 lnschoolsize, robust
est sto row9

esttab row* , b(%9.3f) se(%9.3f) title(Associations between school size and school characteristics ) nogaps star( * 0.1 ** 0.05 *** 0.01) compress
