clear all

set more off
cap log close
set logtype text, perm
log using RESULTS_JLEO_accepted, replace



*********************************************
****   RESULTS AT SCHOOL LEVEL       ********
*********************************************
use  data/CITO_MULTIPLE_YEARS

xtset gemcode

bys gemcode jaar: gen teller=_n

********************************************
******RESULTS ALL YEARS: 1992, 1999-2003****
********************************************

/// Table 3: reduced form
qui xi: xtreg cito lophef lbevolking share190 share125 percentbenefits  share190school share125school i.jaar*i.ophef1992 i.jaar*urban, cluster(gemcode) fe 
est store reducedallyears

///Table 4: Scale vs supply
qui xi: xtreg lnschools lophef lnpupils lbevolking share190 share125 percentbenefits  share190school share125school i.jaar*i.ophef1992 i.jaar*urban, cluster(gemcode) fe 
est store firstallyears_lnschools
test lophef lnpupils

qui xi: xtreg lschoolsize lophef lnpupils lbevolking share190 share125 percentbenefits  share190school share125school i.jaar*i.ophef1992 i.jaar*urban, cluster(gemcode) fe 
est store firstallyears_lschoolsize
test lophef lnpupils

qui xi: xtivreg2 cito (lnschools lschoolsize=lophef lnpupils) lbevolking share190 share125 percentbenefits  share190school share125school i.jaar*i.ophef1992 i.jaar*urban, cluster(gemcode) fe first
est store doubleivallyears

/// show results in table
noi esttab reducedallyears firstallyears_lnschools firstallyears_lschoolsize doubleivallyears, b se starlevels(* .1 ** .05 *** .01) keep (lophef lnschools lschoolsize lophef lnpupils) compress title(Results All years)


/// Table A: share of cito test takers
bys gemcode jaar: gen shareschoolcito=_N/nschools

qui xi: xtreg shareschoolcito lophef lbevolking share190 share125 percentbenefits  share190school share125school i.jaar*i.ophef1992 i.jaar*urban, cluster(gemcode) fe 
est store deelnemersallyears

noi esttab deelnemersallyears, b se starlevels(* .1 ** .05 *** .01) keep (lophef) compress title( table A: share of schools taking cito, all years)


************************************************
*** MAIN RESULTS: school level, 1992 & 2003 ****
************************************************
**** alleen 1992 & 2003
keep if jaar==1992 | jaar==2003
*** ALLEEN GEMEENTES DIE IN 1992 & 2003 CITO GEGEVENS HEBBEN
keep if gemin1992en2003==1


************************************
**** TABLE 1 SUMMARY STATISTICS ****
************************************

bys jaar: sum cito 
bys jaar: sum nschools avrschoolsize ophef1992 ophef1994   ///
 bevolking npupils share125 percentbenefits share190 if teller==1 

 
****************************************
** TABLE 2 instrument validity check ***
****************************************
 
qui xi: xtreg  lbevolking lophef i.jaar*i.ophef1992 i.jaar*urban, fe cluster(gemcode)
est store check1
qui xi: xtreg  lnpupils lophef i.jaar*i.ophef1992 i.jaar*urban, fe cluster(gemcode)
est store check2
qui xi: xtreg  percentbenefits lophef i.jaar*i.ophef1992 i.jaar*urban, fe cluster(gemcode)
est store check3
qui xi: xtreg  share190 lophef i.jaar*i.ophef1992 i.jaar*urban, fe cluster(gemcode)
est store check4

noi esttab check*, b se starlevels(* .1 ** .05 *** .01) keep (lophef) compress title( table 2: instrument validity check)


 
************************************
**** TABLE 3 REDUCED FORM       ****
************************************

qui xi: xtreg  cito  lophef  i.jaar, fe cluster(gemcode)
est store tab3col1
qui xi: xtreg  cito  lophef lbevolking share190 share125 percentbenefits i.jaar, cluster(gemcode) fe
est store tab3col2
qui xi: xtreg  cito  lophef lbevolking share190 share125 percentbenefits i.jaar*i.ophef1992, cluster(gemcode) fe
est store tab3col3
qui xi: xtreg  cito  lophef lbevolking share190 share125 percentbenefits i.jaar*i.ophef1992 i.jaar*urban, cluster(gemcode) fe
est store tab3col4
qui xi: xtreg  cito  lophef lbevolking share190 share125 percentbenefits  share190school share125school i.jaar*i.ophef1992 i.jaar*urban, cluster(gemcode) fe
est store tab3col5
qui xi: xtreg  cito  lophef lbevolking share190 share125 percentbenefits  share190school share125school i.jaar*i.ophef1992 i.jaar*urban if y92grote20==0, cluster(gemcode) fe
est store tab3col6

noi esttab tab3col*, b se starlevels(* .1 ** .05 *** .01) keep (lophef) compress title( table 3: reduced form, school level)

/*====================================*/
/// TABLE 4 SCALE VERSUS SUPPLY
/*====================================*/

*** first stage: lnschools

qui {
xi: xtreg lnschools lophef lnpupils i.jaar, fe cluster(gemcode)
est store firstlnschools1
xi: xtreg lnschools lophef lnpupils  lbevolking share190 share125 percentbenefits i.jaar, cluster(gemcode) fe
est store firstlnschools2
xi: xtreg lnschools lophef lnpupils  lbevolking share190 share125 percentbenefits i.jaar*i.ophef1992, cluster(gemcode) fe
est store firstlnschools3
xi: xtreg lnschools lophef lnpupils  lbevolking share190 share125 percentbenefits i.jaar*i.ophef1992 i.jaar*urban, cluster(gemcode) fe
est store firstlnschools4
xi: xtreg lnschools lophef lnpupils  lbevolking share190 share125 percentbenefits share190school share125school i.jaar*i.ophef1992 i.jaar*urban, cluster(gemcode) fe
est store firstlnschools5
xi: xtreg lnschools lophef lnpupils  lbevolking share190 share125 percentbenefits  share190school share125school i.jaar*i.ophef1992 i.jaar*urban if y92grote20==0, cluster(gemcode) fe
est store firstlnschools6
}

*** first stage: lnschools
qui{
xi: xtreg lschoolsize lophef lnpupils i.jaar, fe cluster(gemcode)
est store firstlschoolsize1
xi: xtreg lschoolsize lophef lnpupils  lbevolking share190 share125 percentbenefits i.jaar, cluster(gemcode) fe
est store firstlschoolsize2
xi: xtreg lschoolsize lophef lnpupils  lbevolking share190 share125 percentbenefits i.jaar*i.ophef1992, cluster(gemcode) fe
est store firstlschoolsize3
xi: xtreg lschoolsize lophef lnpupils  lbevolking share190 share125 percentbenefits i.jaar*i.ophef1992 i.jaar*urban, cluster(gemcode) fe
est store firstlschoolsize4
xi: xtreg lschoolsize lophef lnpupils  lbevolking share190 share125 percentbenefits share190school share125school i.jaar*i.ophef1992 i.jaar*urban, cluster(gemcode) fe
est store firstlschoolsize5
xi: xtreg lschoolsize lophef lnpupils  lbevolking share190 share125 percentbenefits  share190school share125school i.jaar*i.ophef1992 i.jaar*urban if y92grote20==0, cluster(gemcode) fe
est store firstlschoolsize6
}

***second stage
qui xi: xtivreg2 cito (lnschools lschoolsize =lophef lnpupils) i.jaar, fe cluster(gemcode) first
est store secondscalesupply1
qui xi: xtivreg2 cito (lnschools lschoolsize =lophef lnpupils) lbevolking share190 share125 percentbenefits i.jaar, cluster(gemcode) fe first
est store secondscalesupply2
qui xi: xtivreg2 cito (lnschools lschoolsize =lophef lnpupils) lbevolking share190 share125 percentbenefits i.jaar*i.ophef1992, cluster(gemcode) fe first
est store secondscalesupply3
qui xi: xtivreg2 cito (lnschools lschoolsize =lophef lnpupils) lbevolking share190 share125 percentbenefits i.jaar*i.ophef1992 i.jaar*urban, cluster(gemcode) fe first
est store secondscalesupply4
qui xi: xtivreg2 cito (lnschools lschoolsize =lophef lnpupils) lbevolking share190 share125 percentbenefits  share190school share125school i.jaar*i.ophef1992 i.jaar*urban, cluster(gemcode) fe first
est store secondscalesupply5
qui xi: xtivreg2 cito (lnschools lschoolsize =lophef lnpupils) lbevolking share190 share125 percentbenefits share190school share125school i.jaar*i.ophef1992 i.jaar*urban if y92grote20==0, cluster(gemcode) fe first
est store secondscalesupply6



noi esttab firstlnschools*, b se starlevels(* .1 ** .05 *** .01) keep (lophef lnpupils) compress title( table 7: first stage results lnschools, school level 1992, 2003)

noi esttab firstlschoolsize*, b se starlevels(* .1 ** .05 *** .01) keep (lophef lnpupils) compress title( table 7: first stage results lschoolsize, school level 1992, 2003)

noi esttab secondscalesupply*, b se starlevels(* .1 ** .05 *** .01) keep (lnschools lschoolsize) compress title( table 7: second stage results scale vs supply, school level 1992, 2003)



**************************************************************************
*** footnote 14: share schools within 25 pupils of min schoolsize rule ***
**************************************************************************

gen withinrange=0
replace withinrange=1 if jaar==1992 & inrange( Schoolsize, ophef1992-25, ophef1992+25)
replace withinrange=1 if jaar==2003 & inrange( Schoolsize, ophef1994-25, ophef1994+25)

bys jaar brin: gen wr=1 if withinrange==1 & _n==1
bys jaar gemcode: egen schoolswithin=total(wr)

bys jaar brin: gen ss=1 if _n==1
bys jaar gemcode: egen schools=total(ss)

bys gemcode jaar: gen sharewithin=schoolswithin/schools

xi: xtivreg2 cito lophef lbevolking share190 share125 percentbenefits  share190school share125school i.jaar*i.ophef1992 i.jaar*urban sharewithin, cluster(gemcode) fe first
xi: xtivreg2 cito (lnschools lschoolsize=lophef lnpupils) lbevolking share190 share125 percentbenefits share190school share125school i.jaar*i.ophef1992 i.jaar*urban sharewithin, cluster(gemcode) fe first


***************************************************************
*** Table A: share of schools participating in cito test ******
***************************************************************

qui xi: xtreg shareschoolcito lophef i.jaar, fe cluster(gemcode)
est store share1
qui xi: xtreg shareschoolcito lophef lbevolking share190 share125 percentbenefits i.jaar, cluster(gemcode) fe
est store share2
qui xi: xtreg shareschoolcito lophef lbevolking share190 share125 percentbenefits i.jaar*i.ophef1992, cluster(gemcode) fe
est store share3
qui xi: xtreg shareschoolcito lophef lbevolking share190 share125 percentbenefits i.jaar*i.ophef1992 i.jaar*urban, cluster(gemcode) fe
est store share4
qui xi: xtreg shareschoolcito lophef lbevolking share190 share125 percentbenefits  share190school share125school i.jaar*i.ophef1992 i.jaar*urban, cluster(gemcode) fe
est store share5
qui xi: xtreg shareschoolcito lophef lbevolking share190 share125 percentbenefits  share190school share125school i.jaar*i.ophef1992 i.jaar*urban if y92grote20==0, cluster(gemcode) fe
est store share6


noi esttab share*, b se starlevels(* .1 ** .05 *** .01) keep (lophef) compress title( table A: share of schools taking cito, school level 1992 &2003)


************************************************************
*** Table 6: Effect of the number of schools on sorting ***
************************************************************

*** SMALL SAMPLE: ONLY SCHOOLS WITH CITO TEST SCORES

/* heterogeneity index based on three groups 1.9 pupils 1.25 pupils and other pupils */

bys brin jaar: gen HschoolA=1-(Saantal2/Schoolsize)^2-( Saantal5/ Schoolsize)^2-((Schoolsize-Saantal2-Saantal5)/ Schoolsize)^2
bys gemcode jaar: gen HgemeenteA=1-( aantal2/ npupils)^2-( aantal5/npupils)^2-(( npupils- aantal2- aantal5)/ npupils)^2
gen HrelativeA= HschoolA/ HgemeenteA


/* heterogeneity index based on two groups 1.9 pupils and non-1.9 pupils */

bys brin jaar: gen HschoolB=1-( Saantal5/ Schoolsize)^2-((Schoolsize-Saantal5)/ Schoolsize)^2
bys gemcode jaar: gen HgemeenteB=1-( aantal5/npupils)^2-(( npupils- aantal5)/ npupils)^2
gen HrelativeB= HschoolB/ HgemeenteB


sum HschoolA HgemeenteA HrelativeA
sum HschoolB HgemeenteB HrelativeB


qui xi: xtreg  HrelativeA lophef lbevolking percentbenefits  i.jaar*i.ophef1992 i.jaar*urban, cluster(gemcode) fe 
est store sortingsmall1
qui xi: xtreg  HrelativeB lophef lbevolking percentbenefits  i.jaar*i.ophef1992 i.jaar*urban, cluster(gemcode) fe 
est store sortingsmall2
noi esttab sortingsmall*, b se starlevels(* .1 ** .05 *** .01) keep (lophef) compress title( table 6: Sorting, only schools with cito)

**** BIG SAMPLE: ALL SCHOOLS IN 1992 & 2003

use raw/LL, clear
sort brin

/* merge school id's (brin) to municipality id's (gemcode) */

merge brin using data/brin_gem_1obsperbrin
keep if _merge==3
drop _merge
sort gemcode jaar

/* merge municipality information to the school dataset */

merge gemcode jaar using data/geminfo_multipleyears, uniqusing
tab _merge
keep if _merge==3

keep if jaar==1992 | jaar==2003

gen lnschools = ln(nschools)
gen lbevolking = ln(bevolking)
gen lophef=ln(ophef1992) if jaar==1992
replace lophef=ln(ophef1994) if  jaar==2003
gen percentww=100*ww/bevolking
gen percentabw=100*abw/bevolking
gen percentbenefits=100*(abw+ww)/bevolking
gen share190= aantal5/npupils
gen share125=aantal2/npupils

/* generate (relative) heterogeneity indexes */

bys gemcode jaar: egen totaantal2=total(aantal2)
bys gemcode jaar: egen totaantal5=total(aantal5)

/* heterogeneity index based on three groups 1.9 pupils 1.25 pupils and other pupils */

bys brin jaar: gen HschoolA=1-(aantal2/total)^2-( aantal5/ total)^2-((total-aantal2-aantal5)/ total)^2
bys gemcode jaar: gen HgemeenteA=1-( totaantal2/ npupils)^2-( totaantal5/npupils)^2-(( npupils- totaantal2- totaantal5)/ npupils)^2
gen HrelativeA= HschoolA/ HgemeenteA


/* heterogeneity index based on two groups 1.9 pupils and non-1.9 pupils */

bys brin jaar: gen HschoolB=1-( aantal5/ total)^2-((total-aantal5)/ total)^2
bys gemcode jaar: gen HgemeenteB=1-( totaantal5/npupils)^2-(( npupils- totaantal5)/ npupils)^2
gen HrelativeB= HschoolB/ HgemeenteB

sum HschoolA HgemeenteA HrelativeA
sum HschoolB HgemeenteB HrelativeB

xtset gemcode
qui xi: xtreg  HrelativeA lophef lbevolking percentbenefits i.jaar*i.ophef1992 i.jaar*urban, cluster(gemcode) fe
est store sortingbig1
qui xi: xtreg  HrelativeB lophef lbevolking percentbenefits i.jaar*i.ophef1992 i.jaar*urban, cluster(gemcode) fe
est store sortingbig2
noi esttab sortingbig*, b se starlevels(* .1 ** .05 *** .01) keep (lophef ) compress title( table 6: Sorting, all schools)


****************************************
***     RESULTS AT PUPIL LEVEL     *****
****************************************

use  data/CITO_MULTIPLE_YEARS, clear
expand ntesttakers

xtset gemcode
**** alleen 1992 & 2003
keep if jaar==1992 | jaar==2003
*** ALLEEN GEMEENTES DIE IN 1992 & 2003 CITO GEGEVENS HEBBEN
keep if gemin1992en2003==1


/// Table 3: Reduced form
qui xi: xtreg cito lophef lbevolking share190 share125 percentbenefits  share190school share125school i.jaar*i.ophef1992 i.jaar*urban, cluster(gemcode) fe 
est store reducedpupillevel

///Table 7: Scale vs supply
qui xi: xtreg lnschools lophef lnpupils lbevolking share190 share125 percentbenefits  share190school share125school i.jaar*i.ophef1992 i.jaar*urban, cluster(gemcode) fe 
est store firstpupillevel_lnschools
test lophef lnpupils

qui xi: xtreg lschoolsize lophef lnpupils lbevolking share190 share125 percentbenefits  share190school share125school i.jaar*i.ophef1992 i.jaar*urban, cluster(gemcode) fe 
est store firstpupillevel_lschoolsize
test lophef lnpupils

qui xi: xtivreg2 cito (lnschools lschoolsize=lophef lnpupils) lbevolking share190 share125 percentbenefits  share190school share125school i.jaar*i.ophef1992 i.jaar*urban, cluster(gemcode) fe first
est store doubleivpupillevel

/// show results in table
noi esttab reducedpupillevel firstpupillevel_lnschools firstpupillevel_lschoolsize doubleivpupillevel, b se starlevels(* .1 ** .05 *** .01) keep (lophef lnschools lschoolsize lophef lnpupils) compress title(Results Pupil Level)

/// Table A: share of cito test takers
preserve
sort gemcode jaar
merge gemcode jaar using raw/pupils11jaar.dta, uniqusing
tab _merge
keep if _merge==3

bys gemcode jaar: gen deelnemers=_N

gen sharedeelnemers= deelnemers/aantal11jaar

qui xi: xtreg sharedeelnemers lophef lbevolking share190 share125 percentbenefits  share190school share125school i.jaar*i.ophef1992 i.jaar*urban, cluster(gemcode) fe 
est store deelnemerspupillevel

/// show results in table
noi esttab deelnemerspupillevel, b se starlevels(* .1 ** .05 *** .01) keep (lophef) compress title( table A: share of pupils taking cito)

restore


****************************************************
*** TABLE 7: relative & absolute school size     ***
****************************************************

*** generate variable with the minimum, maximum and mean school size over all schools in a municipality in 1992
use  raw/LL, clear
keep if jaar==1992
merge 1:1 brin using data/brin_gem_1obsperbrin
keep if _merge==3
drop _merge
bys gemcode: egen maxsize=max( total)
bys gemcode: egen minsize=min( total)
bys gemcode: egen meansize=mean( total)
rename total schoolsize
keep brin jaar gemcode maxsize minsize meansize schoolsize
sort brin

tempfile minmax
save `minmax', replace


*** merge info on maximum and minimum school size to data set with test scores
use  data/CITO_MULTIPLE_YEARS, clear

keep if jaar==1992

collapse cito gemcode npupils nschools lnpupils lbevolking share* y92grote20 ophef1994 ophef1992 aantal* Saantal*, by(brin)

merge 1:1 brin using `minmax'
keep if _merge==3

xtset gemcode


*** generate relatiev size & log absolute school size variables
gen relativesize=(schoolsize-minsize)/(maxsize-minsize)
gen lschoolsize=ln(schoolsize)


/// Relative school size
qui xtreg cito relativesize lschoolsize ,fe cluster(gemcode)
est store relative1

qui xtreg cito relativesize lschoolsize share125school share190school ,fe cluster(gemcode)
est store relative1b

qui xtreg cito relativesize lschoolsize if y92grote20==0,fe cluster(gemcode)
est store relative2

qui xtreg cito relativesize lschoolsize share125school share190school if y92grote20==0,fe cluster(gemcode)
est store relative2b

*Tables
esttab relative1* relative2*, b(%9.3f) se(%9.3f) keep(relativesize lschoolsize share125school share190school) ///
	title(Relation average cito by school and (relative) schoolsize in 1992, with and without controls ) nogaps star( * 0.1 ** 0.05 *** 0.01) compress


***************************************************************************
**** TABLE 5: Associations between school size and school characteristics**
***************************************************************************

do leo.do
